#/bin/bash
#
# All Rights Reserved, Copyright (c) FUJITSU LIMITED 2012-2014
#
#	Configuration Tool for Oracle VM Server for SPARC
#
# Revision 2.2  2014/10/02
#
# pattern1_guest.sh

guest_pattern1()
{

#---set default------------------------------------------------------------#
CPU_MIN=1
CPU_DEF=1
MEM_MIN=4096
MEM_DEF=4096
NET="net0 net1 net4"
AUTOBOOT=false
BOOTDISK=vdisk0
VCPORT=5000
VDS="primary-vds0"
MIN_VDISK=1
#--------------------------------------------------------------------------#
#DOMAIN="guest"
TITLE=" 2.Configure a Guest Domain"
DKIND="guest"
PATTERN="Pattern 1"
#work_out="${work_dir}/${DOMAIN}"

#--------------------------------------------------------------------------#

############################################################################
# Creating Domain
############################################################################
dom_title()
{
	print "# Logical domain name                                                            [1/6]"
	print ""
	print "Specify a logical domain name for the guest domain. "
	print ""
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""
}

header "$TITLE" "$PATTERN"
dom_title
NUM=1
domain_no

NUM_DOM=`expr $NUM`
GUEST_COUNT=0
while [ $GUEST_COUNT -lt $NUM_DOM ]
do
	echo ""
	h01=`expr $GUEST_COUNT + 1`
	case $h01 in
			[1])	echo "=== Creating the 1st Domain ==="
			;;
			[2])	header "$TITLE" "$PATTERN" ; dom_title
			echo "=== Creating the 2nd Domain ==="
			;;
			[3])	header "$TITLE" "$PATTERN" ; dom_title
			echo "=== Creating the 3rd Domain ==="
			;;
			[4-10])	header "$TITLE" "$PATTERN" ; dom_title
			echo "=== Creating the ${h01}th Domain ==="
			;;
			*)	header "$TITLE" "$PATTERN" ; dom_title
			echo "=== Creating next Domain ==="
			;;
	esac

	domain_name

	work_out="${work_dir}/${DOMAIN}"

	echo ""
	echo "=== The following logical domain name will be set ==="
	echo "Domain : $DOMAIN" | tee -a $work_out/dom.tmp
	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key

############################################################################
# Assign CPU
############################################################################

	print_cpu
	header "$TITLE" "$PATTERN"
	print "# CPU core                                                                       [2/6]"
	print ""
	printf "Assign CPU cores to the domain %s.\n" "$DOMAIN"
	print ""
	print "### Current CPU allocation for each domain ###"
	print ""
	cat $work_dir/cpulist.tmp
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""

	domain_cpu 1

	if [ -f $work_out/cpu.info ];then
		echo "=== The following quantity of CPU cores will be allocated ==="
		cat $work_out/cpu.info
	else
		echo ""
		echo "CPU core will not be allocated."
	fi
	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key

############################################################################
# Assign memory to the guest domain. 
############################################################################

	header "$TITLE" "$PATTERN"
	print_memory

	print "# Memory                                                                         [3/6]"
	print ""
	printf "Assign memory to the domain %s.\n" "$DOMAIN"
	print ""
	print "### The current amount of memory allocated to each domain ###"
	print ""
	cat $work_dir/memlist.tmp
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""

	domain_memory

	echo "=== The following memory will be allocated ==="
	cat $work_out/mem.tmp
	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key

############################################################################
# Creating VDISK
############################################################################

	header "$TITLE" "$PATTERN"

	print "# Virtual Disk                                                                   [4/6]"
	print ""
	print "Do you wish to create a virtual disk (vdisk)?"
	print ""
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""

	make_vdisk 1 0 $VDS

	if [ -f $work_out/gvds.info ];then
		echo ""
		echo "=== The following virtual disk configurations have been set ==="
		cat $work_out/gvds.info
	else
		echo ""
		echo "A virtual disk was not created."
		rm $work_out/gvds.tmp > /dev/null 2>&1
		rm $work_out/gvds.info > /dev/null 2>&1
	fi
	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key

############################################################################
# Confirm VNET
############################################################################

	header "$TITLE" "$PATTERN"
	print "# Confirm VSW(Virtual Switch) and VNET(Virtual Network)                          [5/6]"
	print ""
	print "Please confirm the virtual Switch and the virtual network."
	print ""
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""
	echo "=== The following virtual switch services and virtual networks will be set ==="

	LAN=(The_External_LAN1 The_External_LAN2 The_Management_LAN)
	k=0
	for i in $NET
	do
		echo "VNET   : vnet$k primary-vsw$k" >> $work_out/vnet.tmp
		PYS="`dladm show-phys | grep -w $i | awk '{print $6}'`"
		echo ${LAN[$k]} | tee -a $work_out/vnet.info
		echo "VNET   : vnet$k" | tee -a $work_out/vnet.info
		echo "VSW    : primary-vsw$k" | tee -a $work_out/vnet.info
		echo "NIC    : $i ( physical : $PYS )" | tee -a $work_out/vnet.info
		k=`expr $k + 1`
	done

	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key

############################################################################
# Confirm VC
############################################################################
	header "$TITLE" "$PATTERN"
	print "# Virtual Console                                                                [6/6]"
	print ""
	print "Please confirm the virtual console."
	print ""
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""

	PORT=`expr $VCPORT + $GUEST_COUNT`

	echo "VC     : primary-vcc0 $PORT" >> $work_out/vc.tmp
	echo "=== The following virtual console settings will be made ==="
	echo "VC     : the virtual console concentrator is primary-vcc0" | tee -a $work_out/vc.info
	echo "VC     : the port number is $PORT" | tee -a $work_out/vc.info
	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key

	GUEST_COUNT=`expr $GUEST_COUNT + 1`

############################################################################
# Setting Variables
############################################################################

	echo "OBP    : auto-boot?=$AUTOBOOT $DOMAIN" >> $work_out/var.tmp
	echo "OBP    : boot-disk=$BOOTDISK $DOMAIN" >> $work_out/var.tmp

	echo "OBP    : $DOMAIN : auto-boot?=$AUTOBOOT" >> $work_out/var.info
	echo "OBP    : $DOMAIN : boot-disk=$BOOTDISK" >> $work_out/var.info

done

############################################################################
# Method of installing Solaris OS
############################################################################

header "$TITLE" "$PATTERN"
print "# OS Install                                                                    "
print ""
printf "Select a method to install the Oracle Solaris OS on the logical domain %s.\n" "$DOMAIN"
print "Please select either installation from a network install server for from an iso image"
print "file."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

cp $work_out/vnet.tmp $work_dir
work_out=$work_dir

os_install 0

if [ -f $work_dir/os.tmp ];then
	FILE=`ls -l $work_dir|grep drwxr-xr-x|awk -F" " '{print $9}'`
	for i in $FILE
	do
		cp $work_dir/os.tmp $work_dir/$i/.
	done
fi
print ""
echo "=== The following method will be set ==="
cat $work_dir/os.info
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Confirmation of setting
############################################################################

header "$TITLE" "$PATTERN"
print "The following guest domain configuration will be set."
print ""

FILE=`ls -l $work_dir|grep drwxr-xr-x|awk -F" " '{print $9}'`
for i in $FILE
do
	printf "======= Your configuration information for guest domain %s ======================\n" "$i"
	cat $work_dir/$i/dom.tmp
	cat $work_dir/$i/cpu.info
	cat $work_dir/$i/mem.tmp
	print "-------------------------------------------------------------------"
	if [ -f $work_dir/$i/gvds.info ];then cat $work_dir/$i/gvds.info
		print "-------------------------------------------------------------------"
	fi
	cat $work_dir/$i/vnet.info
	print "-------------------------------------------------------------------"
	cat $work_dir/$i/vc.info
	cat $work_dir/$i/var.info
	print "-------------------------------------------------------------------"
	cat $work_dir/os.info
	print "======================================================================================="
	print ""
done

############################################################################
# Execution and creating of configuration file
############################################################################

EXE=$conf_dir/${DOMAIN}-${DATE}.sh

save_exec 1

############################################################################
# Delete temporary file 
############################################################################

delete
############################################################################

}
