#/bin/bash
#
# All Rights Reserved, Copyright (c) FUJITSU LIMITED 2012-2014
#
#	Configuration Tool for Oracle VM Server for SPARC
#
# Revision 2.2  2014/10/02
#
# pattern2_io.sh

io_pattern2()
{

#---set default------------------------------------------------------------#
CPU_MIN=1
CPU_DEF=1
MEM_MIN=4096
MEM_DEF=4096
AUTOBOOT=false
VCC=primary-vcc0
VCPORT=5000
if [ "$MODEL" = "M10-1" -o "$MODEL" = "M10-4" -o "$MODEL" = "M10-4S" ];then
	IODEV="pci@8100"
elif [ "$MODEL" = "T4-2" -o "$MODEL" = "T4-4" ];then
	IODEV="pci@500"
fi
#--------------------------------------------------------------------------#
TITLE=" 2.Configure a I/O Domain"
DKIND="I/O"
PATTERN="Pattern 2"
#work_out="${work_dir}/${DOMAIN}"

############################################################################
# Creating Domain 
############################################################################

header "$TITLE" "$PATTERN"
print "# Logical domain name                                                            [1/5]"
print ""
print "Specify a logical domain name for the I/O domain.  "
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_name

work_out="${work_dir}/${DOMAIN}"

echo ""
echo "=== The following logical domain name will be set ==="
echo "Domain : $DOMAIN" | tee -a $work_out/dom.tmp
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Adding I/O 
############################################################################

header "$TITLE" "$PATTERN"
print "# Confirm add I/O device                                                         [2/5]"
print ""
printf "Confirm add I/O devices to the domain %s\n" "$DOMAIN"
print ""
print_io
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

echo "=== Confirm added I/O devices ==="
for i in $IODEV
do
	echo "I/O    : added $i to the domain $DOMAIN." | tee -a $work_out/add_io.tmp
done
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Assign CPU
############################################################################

print_cpu

header "$TITLE" "$PATTERN"
print "# CPU core                                                                       [3/5]"
print ""
printf "Assign CPU cores to the domain %s.\n" "$DOMAIN"
print ""
print "### Current CPU allocation for each domain ###"
print ""
cat $work_dir/cpulist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_cpu 1

if [ -f $work_out/cpu.info ];then
	echo "=== The following quantity of CPU cores will be allocated ==="
	cat $work_out/cpu.info
else
	echo ""
	echo "CPU core will not be allocated."
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting Memory
############################################################################

header "$TITLE" "$PATTERN"
print_memory

print "# Memory                                                                         [4/5]"
print ""
printf "Assign memory to the domain %s.\n" "$DOMAIN"
print ""
print "### The current amount of memory allocated to each domain ###"
print ""
cat $work_dir/memlist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""
domain_memory

if [ -f $work_out/mem.tmp ];then
	echo "=== The following memory will be allocated ==="
	cat $work_out/mem.tmp
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting VC
############################################################################

echo "VC     : the virtual console concentrator is $VCC " >> $work_out/vc.info
echo "VC     : the port number is $VCPORT" >> $work_out/vc.info
echo "VC     : $VCC $VCPORT" >> $work_out/vc.tmp

############################################################################
# Setting Variables
############################################################################

echo "OBP    : auto-boot?=$AUTOBOOT" >> $work_out/var.tmp

############################################################################
# Select OS install
############################################################################

header "$TITLE" "$PATTERN"
print "# OS Install                                                                     [5/5]"
print ""
printf "Select a method to install the Oracle Solaris OS on the logical domain %s.\n" "$DOMAIN"
print "Please select either installation from a network install server for from an iso image"
print "file."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

os_install 0

print ""
echo "=== The following method will be set ==="
cat $work_out/os.info
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Confirmation of setting
############################################################################

header "$TITLE" "$PATTERN"
print "The following I/O domain configuration will be set."
print ""
printf "======= Your configuration information for I/O domain %s =========================\n" "$DOMAIN"
cat $work_out/dom.tmp
cat $work_out/cpu.info
cat $work_out/mem.tmp
print "-------------------------------------------------------------------"
cat $work_out/add_io.tmp
cat $work_out/vc.info
cat $work_out/var.tmp
print "-------------------------------------------------------------------"
cat $work_out/os.info
print "======================================================================================="
print ""

############################################################################
# Execution and creating of configuration file
############################################################################

EXE=$conf_dir/${DOMAIN}-${DATE}.sh

save_exec 0

############################################################################
# Delete temporary file 
############################################################################

delete
############################################################################

}
