#/bin/bash
#
# All Rights Reserved, Copyright (c) FUJITSU LIMITED 2012-2014
#
#	Configuration Tool for Oracle VM Server for SPARC
#
# Revision 2.2  2014/10/02
#
# pattern2_primary.sh

primary_pattern2()
{
DOMAIN=primary

#---set default------------------------------------------------------------#
CPU_MIN=4
CPU_DEF=4
MEM_MIN=8192
MEM_DEF=8192
STPORT="5000"
EDPORT="5100"
CONFIG=config_initial
IODEV="pci@8100"
if [ "$MODEL" = "T4-2" -o "$MODEL" = "T4-4" ];then
	IODEV="pci@500"
fi

#--------------------------------------------------------------------------#
TITLE=" 1.Configure a Primary Domain"
DKIND="primary"
PATTERN="Pattern 2"
work_out="${work_dir}"

############################################################################
# Confirm removed I/O devices
############################################################################

header "$TITLE" "$PATTERN"
print "# Confirm removed I/O devices                                                    [1/3]"
print ""
print "Please confirm I/O devices to remove from primary domain."
print ""
print "### The current allocation of the I/O device ###"
print ""
print_io
print ""
print "---------------------------------------------------------------------------------------"
print ""

echo "=== Confirm removed I/O devices ===" 
echo "I/O    : $IODEV removed from the primary domain" | tee -a $work_dir/remove_io.tmp
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Assign CPU
############################################################################

header "$TITLE" "$PATTERN"
print_cpu
print "# CPU cores                                                                      [2/3]"
print ""
print "Assign CPU cores to the primary domain."
print ""
cat $work_dir/cpulist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_cpu 1

if [ -f $work_out/cpu.info ];then
	echo "=== The following quantity of CPU cores will be allocated ==="
	cat $work_out/cpu.info
else
	echo ""
	echo "CPU core will not be allocated."
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key
	
############################################################################
# Setting Memory
############################################################################

header "$TITLE" "$PATTERN"
print_memory
print "# Memory                                                                         [3/3]"
print ""
print "Assign memory to the primary domain."
print ""
cat $work_dir/memlist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_memory

echo "=== The following memory will be allocated ==="
cat $work_out/mem.tmp
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Check configuration file name
############################################################################

header "$TITLE" "$PATTERN"
CONF_O=$CONFIG
config_name $CONF_O

echo "=== The configuration will be saved as the following ==="
echo "The configuration name : $CONFIG" | tee -a $work_out/config.tmp
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting VCC
############################################################################

echo "VCC    : primary-vcc0 will use the port range of $STPORT to $EDPORT" >> $work_out/vcc.tmp

############################################################################
# Confirm the domain configuration
############################################################################

header "$TITLE" "$PATTERN"
print "The following primary domain configuration will be set."
print ""
print "======= Your configuration information for primary domain ============================="
cat $work_out/remove_io.tmp
cat $work_out/cpu.info
cat $work_out/mem.tmp
print "-------------------------------------------------------------------"
cat $work_out/vcc.tmp
print "-------------------------------------------------------------------"
printf "The configuration name : %s\n" "$CONFIG"
print "======================================================================================="
print ""

############################################################################
# Execution and creating of configuration file
############################################################################

EXE=$conf_dir/${DOMAIN}-${DATE}.sh

save_exec 0

############################################################################
# Delete temporary file 
############################################################################

delete
############################################################################

}
