#/bin/bash
#
# All Rights Reserved, Copyright (c) FUJITSU LIMITED 2012-2016
#
#	Configuration Tool for Oracle VM Server for SPARC
#
# Revision 2.4  2016/11/11
#
# pattern3_io.sh

io_pattern3()
{

#---set default------------------------------------------------------------#
PRIMARY_CPU=4
CPU_MIN=2
CPU_MAX=16
CPU_DEF=2
MEM_MIN=4096
MEM_DEF=4096
AUTOBOOT=false
VCC=primary-vcc0
PORT=5000
VSW=primary-vsw0
#--------------------------------------------------------------------------#
LDM_DEF=3.4
LDM_VER=`pkg info ldomsmanager|grep FMRI|awk -F"@" '{print $2}'|cut -c-3`
SOCKET_FLG=`echo "$LDM_VER - $LDM_DEF" | bc | cut -c 1`
#--------------------------------------------------------------------------#
TITLE=" 2.Configure a I/O Domain"
DKIND="I/O"
PATTERN="Pattern 3"
#work_out="${work_dir}/${DOMAIN}"

#--------------------------------------------------------------------------#
#mkdir $work_dir/$DOMAIN > /dev/null 2>&1

############################################################################
# Creating Domain 
############################################################################

IO_COUNT=0
while [ $IO_COUNT -le 2 ]
do
	header "$TITLE" "$PATTERN"
	print "# Logical domain name                                                            [1/6]"
	print ""
	print "Specify a logical domain name for the I/O domain. "
	print ""
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""
	case $IO_COUNT in
		[0]) echo "=== Creating the 1st I/O Domain ==="
		;;
		[1]) echo "=== Creating the 2nd I/O Domain ==="
		;;
		[2]) echo "=== Creating the 3rd I/O Domain ==="
		;;
	esac

	domain_name
	work_out="${work_dir}/${DOMAIN}"

	host_id

	echo ""
	echo "=== The following logical domain name will be set ==="
	cat $work_out/dom.tmp 
	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key

############################################################################
# Assign CPU
############################################################################

	if [ $SOCKET_FLG != "-" ];then
		CPU_SOCKET=`expr $IO_COUNT + 1`
		echo "CPU    : $CPU_SOCKET $PRIMARY_CPU" >> $work_out/cpu_p3.tmp
		echo "CPU    : CPU_SOCKET is $CPU_SOCKET for the $DOMAIN" >> $work_out/cpu.info
	fi
	print_cpu
	header "$TITLE" "$PATTERN"
	print "# CPU core                                                                       [2/6]"
	print ""
	printf "Assign CPU cores to the domain %s.\n" "$DOMAIN"
	print ""
	print "### Current CPU allocation for each domain ###"
	print ""
	cat $work_dir/cpulist.tmp
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""

	domain_cpu 1

	if [ -f $work_out/cpu.info ];then
		echo "=== The following quantity of CPU cores will be allocated ==="
		cat $work_out/cpu.info
	else
		echo ""
		echo "CPU core will not be allocated."
	fi
	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key

############################################################################
# Setting Memory
############################################################################

#---get Memory-------------------------------------------------------------#

	if [ "$MODEL" = "T4-4" ];then
		case $IO_COUNT in
			[0])	MEM_PA="0x12"	;;
			[1])	MEM_PA="0x82" ;;
			[2])	MEM_PA="0x20" ;;
		esac
	else
		case $IO_COUNT in
			[0])	MEM_PA="0x7c"	;;
			[1])	MEM_PA="0x7a" ;;
			[2])	MEM_PA="0x78" ;;
		esac
	fi

	START_MEM=""
	get_mem_addr $MEM_PA "-v bound="

	echo "Domain Memory(MB)" | awk '{printf"%-1s%-18s%-10s\n","",$1,$2}' > $work_dir/memlist.tmp
	echo "----------------- ----------" | awk '{printf"%-1s%-18s%-10s\n","",$1,$2}' >> $work_dir/memlist.tmp
	ldm ls -p | grep DOMAIN | sed -e 's/name=//' -e 's/mem=//' | awk -F"|" '{printf"%-1s%-18s%10d\n","",$2,$7/1048576}' >> $work_dir/memlist.tmp
	if [ -f $work_dir/mem_$$ ];then
	  cat $work_dir/mem_$$ | awk '{printf"%-1s%-18s%10s%-1s%-15s\n","",$1,$2,"",$3}' >> $work_dir/memlist.tmp
	fi
	echo "----------------------------" | awk '{printf"%-1s%-29s\n","",$1}' >> $work_dir/memlist.tmp
	echo "" >> $work_dir/memlist.tmp
	eval echo "The amount of memory that can be allocated: $NUM_of_REM MB" >> $work_dir/memlist.tmp
	if [ $NUM_of_REM -lt $MEM_MIN ];then
		echo "There is no enough memory resource that can be allocated for the I/O domain." >> $work_dir/memlist.tmp
	fi
	echo "" >> $work_dir/memlist.tmp

#--------------------------------------------------------------------------#

	header "$TITLE" "$PATTERN"
	print "# Memory                                                                         [3/6]"
	print ""
	print "Assign memory to the domain $DOMAIN."
	print ""
	print "### The current amount of memory allocated to each domain ###"
	print ""
	cat $work_dir/memlist.tmp
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""

	if [ "$NUM_of_REM" -lt $MEM_MIN ];then
		echo "This operation is abort. Please press the enter key."
		read key
		delete
		menu
	fi

	while :
	do
		echo "Enter the amount of memory for the I/O domain $DOMAIN. (By multiple of 256MB) [$MEM_DEF](MB)"
		echo "==> \c"
		read MEM
		expr ${MEM:-$MEM_DEF} + 1 > /dev/null 2>&1
		if [ $? = 0 ];then
			if [ ${MEM:-$MEM_DEF} -ge $MEM_MIN -a ${MEM:-$MEM_DEF} -le $NUM_of_REM ];then
				MCHK=`expr ${MEM:-$MEM_DEF} % 256`
				if [ $MCHK = 0 ];then
					echo ""
					echo "=== The following memory will be allocated ==="
					echo "Memory : ${MEM:-$MEM_DEF} MB for the I/O domain $DOMAIN" | tee -a $work_out/mem.info
					if [ $SOCKET_FLG = "-" ];then
						echo "Memory : START_PA = $START_MEM" | tee -a $work_out/mem.info
						echo "ldm set-memory mblock=$START_MEM:${MEM:-$MEM_DEF}M $DOMAIN" >> $work_out/mem_p3.tmp

					else
						echo "Memory : ${MEM:-$MEM_DEF} $DOMAIN $START_MEM" >> $work_out/mem.tmp
					fi
					echo "$DOMAIN ${MEM:-$MEM_DEF} (Reserved)" >> $work_dir/mem_$$
					break
				else
					MEM256="`expr \( $MEM / 256 + 1 \) \* 256`"
					echo ""
					echo "WARNING: A memory capacity for a domain needs to allocate by multiple of 256MB."
					echo "WARNING: Although you set \"${MEM}MB\", \"${MEM256}MB\" was specified to the memory capacity."
					echo ""
					echo "=== The following memory will be allocated ==="
					echo "Memory : $MEM256 MB for the I/O domain $DOMAIN" | tee -a $work_out/mem.info
					if [ $SOCKET_FLG = "-" ];then
						echo "Memory : START_PA = $START_MEM" | tee -a $work_out/mem.info
						echo "ldm set-memory mblock=$START_MEM:${MEM256}M $DOMAIN" >> $work_out/mem_p3.tmp
					else
						echo "Memory : ${MEM256} $DOMAIN $START_MEM" >> $work_out/mem.tmp
					fi
					echo "$DOMAIN ${MEM256:-$MEM_DEF} (Reserved)" >> $work_dir/mem_$$
					break
				fi
			else
				echo "ERROR: Invalid input value."
				echo "ERROR: Please enter a number between $MEM_MIN and $NUM_of_REM."
				echo ""
			fi
		else
			if [ ${MEM:-$MEM_DEF} = t ];then
				top
			elif [ ${MEM:-$MEM_DEF} = q ];then
				quit
			else
				echo "ERROR: Invalid input value."
				echo "ERROR: Please enter a number between $MEM_MIN and $NUM_of_REM."
				echo ""
			fi
		fi
	done

	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key

############################################################################
# Confirm VNET
############################################################################

	header "$TITLE" "$PATTERN"
	print "# VNET                                                                           [4/6]"
	print ""
	printf "Assign VNET(Virtual Network) to the domain %s.\n" "$DOMAIN"
	print ""
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""

	VNET=`ldm ls -l -p | grep VSW | grep $VSW | cut -d "|" -f 2 | cut -d "=" -f 2`
	NIC=`ldm ls -l -p | grep VSW | grep $VSW | cut -d "|" -f 5 | cut -d "=" -f 2`
	if [ -z $NIC ];then
		NIC="physical NIC was not allocated"
	fi
	if [ "$VNET" = "$VSW" ];then
		echo "VNET   : vnet0 $VSW" >> $work_out/vnet.tmp
		echo "=== Confirm added virtual networks will be made ==="
	 	echo "VNET   : vnet0" | tee -a $work_out/vnet.info
		echo "VSW    :" $VSW | tee -a $work_out/vnet.info
		echo "NIC    :" $NIC | tee -a $work_out/vnet.info
	else
		echo "A virtual networks will not be created." | tee -a $work_out/vnet.info
	fi

	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key

############################################################################
# Adding I/O 
############################################################################

	header "$TITLE" "$PATTERN"
	print "# Add I/O devices to the I/O domain.                                             [5/6]"
	print ""
	printf "Please confirm the I/O device to be added to the domain %s\n" "$DOMAIN"
	print ""
	print "### Current I/O device allocation for each domain ###"
	print ""
	print_io
	print ""
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""

	if [ "$MODEL" = "M10-1" -o "$MODEL" = "M10-4" -o "$MODEL" = "M10-4S" ];then
		case $IO_COUNT in
			[0])	IODEV1=pci@8200 ; IODEV2=pci@8300 ;;
			[1])	IODEV1=pci@8400 ; IODEV2=pci@8500 ;;
			[2])	IODEV1=pci@8600 ; IODEV2=pci@8700 ;;
		esac
	else
		case $IO_COUNT in
			[0])	IODEV1=pci@500 ; IODEV2= ;;
			[1])	IODEV1=pci@600 ; IODEV2= ;;
			[2])	IODEV1=pci@700 ; IODEV2= ;;
		esac
	fi

	echo "=== Confirm added I/O devices ==="
	echo "I/O    : added $IODEV1 to the domain $DOMAIN." | tee -a $work_out/add_io.tmp
	echo $IODEV1 $DOMAIN >> $work_dir/io_resv.tmp 
	if [ "$IODEV2" != "" ];then
		echo "I/O    : added $IODEV2 to the domain $DOMAIN." | tee -a $work_out/add_io.tmp
		echo $IODEV2 $DOMAIN >> $work_dir/io_resv.tmp 
	fi
	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key

############################################################################
# Confirm VC
############################################################################
#--set vc------------------------------------------------------------------#
VCPORT=`expr $PORT + $IO_COUNT`
#--------------------------------------------------------------------------#

	header "$TITLE" "$PATTERN"
	print "# Virtual Console                                                                [6/6]"
	print ""
	print "Please confirm the virtual console."
	print ""
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""

	echo "VC     : primary-vcc0 $VCPORT" >> $work_out/vc.tmp
	echo "=== The following virtual console settings will be made ==="
	echo "VC     : the virtual console concentrator is primary-vcc0" | tee -a $work_out/vc.info
	echo "VC     : the port number is $VCPORT" | tee -a $work_out/vc.info
	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key

############################################################################
# Setting Variables
############################################################################

	echo "OBP    : auto-boot?=$AUTOBOOT $DOMAIN" >> $work_out/var.tmp
	echo "OBP    : $DOMAIN : auto-boot?=$AUTOBOOT" >> $work_out/var.info

	IO_COUNT=`expr $IO_COUNT + 1`

done

############################################################################
# Method of installing Solaris OS
############################################################################

header "$TITLE" "$PATTERN"
print "# OS Install                                                                    "
print ""
printf "Select a method to install the Oracle Solaris OS on the logical domain %s.\n" "$DOMAIN"
print "Please select either installation from a network install server for from an iso image"
print "file."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

os_install 0

mv $work_out/os.* $work_dir/.
if [ -f $work_dir/os.tmp ];then
	FILE=`ls -l $work_dir|grep drwxr-xr-x|awk -F" " '{print $9}'`
	for i in $FILE
	do
		cp $work_dir/os.tmp $work_dir/$i/.
	done
fi

echo "=== The following method will be set ==="
cat $work_dir/os.info
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key


############################################################################
# Confirmation of setting
############################################################################

header "$TITLE" "$PATTERN"
print "The following guest domain configuration will be set."
print ""

FILE=`ls -l $work_dir|grep drwxr-xr-x|awk -F" " '{print $9}'`
for i in $FILE
do
	printf "======= Your configuration information for guest domain %s ======================\n" "$i"
	cat $work_dir/$i/dom.tmp
	cat $work_dir/$i/cpu.info
	cat $work_dir/$i/mem.info
	print "-------------------------------------------------------------------"
	cat $work_dir/$i/vc.info
	cat $work_dir/$i/var.info
	print "-------------------------------------------------------------------"
	cat $work_dir/$i/vnet.info
	print "-------------------------------------------------------------------"
	cat $work_dir/$i/add_io.tmp
	print "-------------------------------------------------------------------"
	cat $work_dir/os.info
	print "======================================================================================="
	print ""
done

############################################################################
# Execution and creating of configuration file
############################################################################

save_exec 1

############################################################################
# Delete temporary file 
############################################################################

delete
############################################################################

}
