#/bin/bash
#
# All Rights Reserved, Copyright (c) FUJITSU LIMITED 2012-2016
#
#	Configuration Tool for Oracle VM Server for SPARC
#
# Revision 2.4  2016/11/11
#
# pattern3_primary.sh

primary_pattern3()
{
DOMAIN=primary

#---set default------------------------------------------------------------#
CPU=4
MEM=16384
STPORT="5000"
EDPORT="5100"
CONFIG=config_initial
PRIIO="pci@8000 pci@8100"
MEM_PA="0x7e"
if [ "$MODEL" = "T4-2" -o "$MODEL" = "T4-4" ];then
	PRIIO="pci@400"
	MEM_PA="0x20"
fi
#--------------------------------------------------------------------------#
CPU_SOCKET=0
LDM_DEF=3.4
LDM_VER=`pkg info ldomsmanager|grep FMRI|awk -F"@" '{print $2}'|cut -c-3`
SOCKET_FLG=`echo "$LDM_VER - $LDM_DEF" | bc | cut -c 1`
#--------------------------------------------------------------------------#
TITLE=" 1.Configure a Primary Domain"
DKIND="primary"
PATTERN="Pattern 3"
work_out="${work_dir}"
############################################################################
# Confirm removed I/O devices
############################################################################

header "$TITLE" "$PATTERN"
print "# Confirm removed I/O devices                                                    [1/2]"
print ""
print "Remove some I/O devices from the primary domain."
print "Please confirm removed I/O devices from the primary domain."
print ""
print "### The current allocation of the I/O device ###"
print ""
print_io | tee -a $work_dir/iolist.tmp
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

IODEV=`cat $work_dir/iolist.tmp | awk '{print $2}'`
for i in $PRIIO
do
	IODEV=`echo $IODEV | sed -e 's/'$i'//'`
done

echo "=== Confirm removed I/O devices ===" 
for i in $IODEV
do
	if [ $i != "DeviceName" -a $i != "---------------" ];then
		echo "I/O    : $i removed from the primary domain" | tee -a $work_out/remove_io.tmp
	fi
done
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Creating VSW
############################################################################

header "$TITLE" "$PATTERN"
print "# Create a Virtual switch                                                        [2/2]"
print ""
print "Do you wish to create the virtual switch service (vsw) to connect logical domains by"
print "the virtual network (vnet)?"
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

while :
do
	YN=""
	echo "Create a virtual switch service? ([y]/n) ==> \c"
	read YN
	case ${YN:-y} in
		[t])	top
			;;
		[q])	quit
			;;
		[y])	break
			;;
		[n])	break
			;;
		  *)	continue
			;;
	esac
done

if [ "${YN:-y}" != n ];then
	echo ""
	echo "=== Set the virtual switch service configuration ==="
	add_vsw 0
	if [ -f $work_dir/vsw.tmp ];then
		echo ""
		echo "=== These virtual switch service settings will be created ==="
		cat $work_dir/vsw.info
	else
		echo ""
		echo "A virtual switch service will not be created."
	fi
else
	echo ""
	echo "A virtual switch service will not be created."
	echo "VSW    : A virtual switch service will not be created." >> $work_dir/vsw.info
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Assign CPU
############################################################################

if [ $SOCKET_FLG != "-" ];then
	echo "CPU    : $CPU_SOCKET" >> $work_out/cpu_p3p.tmp
	echo "CPU    : CPU_SOCKET is $CPU_SOCKET for the primary domain" >> $work_out/cpu.info
else
	echo "CPU    : $CPU disabled" >> $work_out/cpu.tmp
	echo "CPU    : $CPU cores for the primary domain" >> $work_out/cpu.info
fi
############################################################################
# Setting Memory
############################################################################

if [ $SOCKET_FLG != "-" ];then
	echo "Memory : $MEM MB for the primary domain $DOMAIN" >> $work_out/mem.tmp
	echo "Memory : $MEM MB for the primary domain" >> $work_out/mem.info
else
	if [ "$MODEL" = "T4-2" -o "$MODEL" = "T4-4" ];then
		echo "Memory : $MEM MB for the primary domain $DOMAIN" >> $work_out/mem.tmp
		echo "Memory : $MEM MB for the primary domain" >> $work_out/mem.info
	else
		START_MEM=""
		get_mem_addr $MEM_PA "bound=primary"
		echo "ldm set-memory mblock=$START_MEM:${MEM}M primary" >> $work_out/mem_p3.tmp
		echo "Memory : $MEM MB for the primary domain" >> $work_out/mem.info
		echo "Memory : START_PA = $START_MEM" >> $work_out/mem.info
	fi
fi
############################################################################
# Setting VCC
############################################################################

echo "VCC    : primary-vcc0 will use the port range of $STPORT to $EDPORT" >> $work_out/vcc.tmp

############################################################################
# Check configuration file name
############################################################################

header "$TITLE" "$PATTERN"
CONF_O=$CONFIG
config_name $CONF_O

echo ""
echo "=== The configuration will be saved as the following ==="
echo "The configuration name : $CONFIG" | tee -a $work_out/config.tmp
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Confirm the domain configuration
############################################################################

header "$TITLE" "$PATTERN"
print "The following primary domain configuration will be set."
print ""
print "======= Your configuration information for primary domain ============================="
cat $work_out/cpu.info
cat $work_out/mem.info
print "-------------------------------------------------------------------"
cat $work_out/vcc.tmp
cat $work_out/vsw.info
print "-------------------------------------------------------------------"
cat $work_dir/remove_io.tmp
print "-------------------------------------------------------------------"
print "The configuration name : $CONFIG"
print "======================================================================================="
print ""

############################################################################
# Execution and creating of configuration file
############################################################################

EXE=$conf_dir/${DOMAIN}-${DATE}.sh

save_exec 0

############################################################################
# Delete temporary file 
############################################################################

delete
############################################################################

}
