#/bin/bash
#
# All Rights Reserved, Copyright (c) FUJITSU LIMITED 2012-2014
#
#	Configuration Tool for Oracle VM Server for SPARC
#
# Revision 2.2  2014/10/02
#
# pattern4_io1.sh

io_chkek()
{
NAME=`ldm ls -p | grep DOMAIN | sed -e 's/name=//' -e 's/ncpu=//' | awk -F"|" '{print $2}'`

case $1 in
	[1])	echo $NAME | grep -w $DOMAIN > /dev/null 2>&1
		if [ $? = 0 ];then
			echo "----------------------------------------------------------------------"
			echo "The logical domain name has already been used."
			echo "This section is already finish."
			echo "----------------------------------------------------------------------"
			echo "Please press the enter key. \c"
			read key
			continue
		fi
		;;
	[2])	DOMAIN_LIST=`ldm ls-io -p | grep type=BUS | awk -F"|" '{print $5}' | sed -e s/domain=// | grep -v primary | sed -e /^$/d | sort -u`
		JG=0
		if [ "$DOMAIN_LIST" != "" ];then
			for i in $DOMAIN_LIST
			do
				DOMAIN_STATUS=`ldm ls -p | grep $i | awk -F"|" '{print $4}' | cut -c 8`
				if [ "$DOMAIN_STATUS" = "n" ];then
					JG=1
				fi
			done
		fi
		if [ $JG = 0 ];then
			echo "---------------------------------------------------------------------------------------"
			echo "There is no I/O domain currently running the Solaris OS. You must first install the"
			echo "Solaris OS and start the I/O domain for which you want to set the service domain."
			echo "---------------------------------------------------------------------------------------"
			echo "Please press the enter key. \c"
			read key
			continue
		fi
		;;
esac
}
io_pattern41()
{

#---set default------------------------------------------------------------#
DOMAIN="iodom0"
CPU_MIN=1
CPU_DEF=1
MEM_MIN=4096
MEM_DEF=4096
AUTOBOOT=false
VNT=vnet0
VSW=primary-vsw0
VCC=primary-vcc0
VCPORT=5000
if [ "$MODEL" = "M10-1" -o "$MODEL" = "M10-4" -o "$MODEL" = "M10-4S" ];then
	IODEV="pci@8200 pci@8300 pci@8400 pci@8500"
elif [ "$MODEL" = "T4-2" -o "$MODEL" = "T4-4" ];then
	IODEV="pci@500"
fi
#--------------------------------------------------------------------------#
TITLE=" 2.Configure a I/O Domain#0"
DKIND="I/O"
PATTERN="Pattern 4"
work_out="${work_dir}/${DOMAIN}"

#--------------------------------------------------------------------------#
mkdir $work_dir/$DOMAIN > /dev/null 2>&1

############################################################################
# Creating Domain 
############################################################################

header "$TITLE" "$PATTERN"
print "# Host ID                                                                        [1/6]"
print ""
print "Specify a host ID for the I/O domain."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

host_id

echo ""
echo "=== The following logical domain name will be set ==="
cat $work_out/dom.tmp
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Assign CPU
############################################################################

print_cpu

header "$TITLE" "$PATTERN"
print "# CPU core                                                                       [2/6]"
print ""
printf "Assign CPU cores to the domain %s.\n" "$DOMAIN"
print ""
print "### Current CPU allocation for each domain ###"
print ""
cat $work_dir/cpulist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_cpu 0

if [ -f $work_out/cpu.info ];then
	echo "=== The following quantity of CPU cores will be allocated ==="
	cat $work_out/cpu.info
else
	echo ""
	echo "CPU core will not be allocated."
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting Memory
############################################################################

header "$TITLE" "$PATTERN"
print_memory

print "# Memory                                                                         [3/6]"
print ""
printf "Assign memory to the domain %s.\n" "$DOMAIN"
print ""
print "### The current amount of memory allocated to each domain ###"
print ""
cat $work_dir/memlist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""
domain_memory

if [ -f $work_out/mem.tmp ];then
	echo "=== The following memory will be allocated ==="
	cat $work_out/mem.tmp
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Adding I/O 
############################################################################

header "$TITLE" "$PATTERN"
print "# Confirm add I/O device                                                         [4/6]"
print ""
printf "Confirm add I/O devices to the domain %s\n" "$DOMAIN"
print ""
print_io
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

echo "=== Confirm added I/O devices ==="
for i in $IODEV
do
	echo "I/O    : added $i to the domain $DOMAIN." | tee -a $work_out/add_io.tmp
done
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Confirm VNET
############################################################################

header "$TITLE" "$PATTERN"
print "# VNET                                                                           [5/6]"
print ""
printf "Assign VNET(Virtual Network) to the domain %s.\n" "$DOMAIN"
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

VNET=`ldm ls -l -p|grep "$VSW" | cut -d "|" -f 2 | cut -d "=" -f 2`
NIC=`ldm ls -l -p|grep "$VSW" | cut -d "|" -f 5 | cut -d "=" -f 2`
if [ -z $NIC ];then
	NIC="physical NIC was not allocated"
fi
if [ "$VNET" = "$VSW" ];then
	echo "=== Confirm added virtual networks will be made ==="
 	echo "VNET   :" $VNT | tee -a $work_out/vnet.info
	echo "VSW    :" $VSW | tee -a $work_out/vnet.info
	echo "NIC    :" $NIC | tee -a $work_out/vnet.info
	echo "VNET   : $VNT $VSW" > $work_out/vnet.tmp
else
	echo "A virtual networks will not be created."
fi

echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Select OS install
############################################################################

header "$TITLE" "$PATTERN"
print "# OS Install                                                                     [6/6]"
print ""
printf "Select a method to install the Oracle Solaris OS on the logical domain %s.\n" "$DOMAIN"
print "Please select either installation from a network install server for from an iso image"
print "file."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

os_install 0

echo "=== The following method will be set ==="
cat $work_out/os.info
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting VC
############################################################################

echo "VC     : the virtual console concentrator is $VCC " >> $work_out/vc.info
echo "VC     : the port number is $VCPORT" >> $work_out/vc.info
echo "VC     : $VCC $VCPORT" >> $work_out/vc.tmp

############################################################################
# Setting Variables
############################################################################

echo "OBP    : auto-boot?=$AUTOBOOT" >> $work_out/var.tmp

############################################################################
# Confirmation of setting
############################################################################

header "$TITLE" "$PATTERN"
print "The following I/O domain configuration will be set."
print ""

printf "======= Your configuration information for I/O domain %s =========================\n" "$DOMAIN"
cat $work_out/dom.tmp
cat $work_out/cpu.info
cat $work_out/mem.tmp
print "-------------------------------------------------------------------"
cat $work_out/add_io.tmp
print "-------------------------------------------------------------------"
cat $work_out/vnet.info
print "-------------------------------------------------------------------"
cat $work_out/vc.info
cat $work_out/var.tmp
print "-------------------------------------------------------------------"
cat $work_out/os.info
print "======================================================================================="
print ""

############################################################################
# Execution and creating of configuration file
############################################################################

EXE=$conf_dir/${DOMAIN}-${DATE}.sh

save_exec 0

############################################################################
# Delete temporary file 
############################################################################

delete
############################################################################

}
