#/bin/bash
#
# All Rights Reserved, Copyright (c) FUJITSU LIMITED 2012-2014
#
#	Configuration Tool for Oracle VM Server for SPARC
#
# Revision 2.2  2014/10/02
#
# pattern4_io3.sh

io_pattern43()
{

#---set default------------------------------------------------------------#
DOMAIN="dbdom0"
CPU_MIN=1
CPU_DEF=1
MEM_MIN=4096
MEM_DEF=4096
AUTOBOOT=false
PVSW="primary-vsw0,vnet0"
LVSW="io-vsw-local1,vnet1"
VCC=primary-vcc0
VCPORT=5030
if [ "$MODEL" = "M10-1" -o "$MODEL" = "M10-4" -o "$MODEL" = "M10-4S" ];then
	IODEV="pci@8600 pci@8700"
elif [ "$MODEL" = "T4-2" -o "$MODEL" = "T4-4" ];then
	IODEV="pci@600 pci@700"
fi
#--------------------------------------------------------------------------#
TITLE=" 4.Configure a I/O Domain#1 (for database server)"
DKIND="I/O"
PATTERN="Pattern 4"
work_out="${work_dir}/${DOMAIN}"

#--------------------------------------------------------------------------#
mkdir $work_dir/$DOMAIN > /dev/null 2>&1

############################################################################
# Creating Domain 
############################################################################

header "$TITLE" "$PATTERN"
print "# Host ID                                                                        [1/7]"
print ""
print "Specify a host ID for the I/O domain."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

host_id

echo ""
echo "=== The following logical domain name will be set ==="
cat $work_out/dom.tmp
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Assign CPU
############################################################################

print_cpu
header "$TITLE" "$PATTERN"
print "# CPU core                                                                       [2/7]"
print ""
printf "Assign CPU cores to the domain %s.\n" "$DOMAIN"
print ""
print "### Current CPU allocation for each domain ###"
print ""
cat $work_dir/cpulist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_cpu 1

if [ -f $work_out/cpu.info ];then
	echo "=== The following quantity of CPU cores will be allocated ==="
	cat $work_out/cpu.info
else
	echo ""
	echo "CPU core will not be allocated."
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting Memory
############################################################################

header "$TITLE" "$PATTERN"
print_memory

print "# Memory                                                                         [3/7]"
print ""
printf "Assign memory to the domain %s.\n" "$DOMAIN"
print ""
print "### The current amount of memory allocated to each domain ###"
print ""
cat $work_dir/memlist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_memory

if [ -f $work_out/mem.tmp ];then
	echo "=== The following memory will be allocated ==="
	cat $work_out/mem.tmp
fi

echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Adding I/O 
############################################################################

header "$TITLE" "$PATTERN"

print "# Confirm add I/O device                                                         [4/7]"
print ""
printf "Confirm add I/O devices to the domain %s\n" "$DOMAIN"
print ""
print_io
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

echo "=== Confirm added I/O devices ==="
for i in $IODEV
do
	echo "I/O    : added $i to the domain $DOMAIN." | tee -a $work_out/add_io.tmp
done
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Confirm VNET
############################################################################

header "$TITLE" "$PATTERN"
print "# VNET                                                                           [5/7]"
print ""
print "This VNET (Virtual Network) is created for the management."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

for i in $PVSW
do
	PNAM=`echo $i|awk -F","  '{print $1}'`
	PNIC=`echo $i|awk -F","  '{print $2}'`
	NIC=`ldm ls -l -p|grep VSW |grep $PNAM | cut -d "|" -f 5 | cut -d "=" -f 2`
	if [ -z $NIC ];then
		NIC="physical NIC was not allocated"
	fi
#	echo "VSW    : $PNAM : $PNIC was allocated." | tee -a $work_out/vnet.tmp
	echo "VNET   : $PNIC $PNAM" >> $work_out/vnet.tmp
	echo "=== Confirm added virtual networks will be made ==="
 	echo "VNET   :" $PNIC | tee -a $work_out/vnet.info
	echo "VSW    :" $PNAM | tee -a $work_out/vnet.info
	echo "NIC    :" $NIC | tee -a $work_out/vnet.info
done

echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Confirm VNET
############################################################################

header "$TITLE" "$PATTERN"
print "# VNET                                                                           [6/7]"
print ""
print "This VNET (Virtual Network) is created for the Inter-Domain connection."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

for i in $LVSW
do
#	echo "VSW    : $i : No physical NIC assigned." | tee -a $work_out/vnet.tmp
	PNAM=`echo $i|awk -F","  '{print $1}'`
	PNIC=`echo $i|awk -F","  '{print $2}'`
	NIC=`ldm ls -l -p|grep $PNAM | cut -d "|" -f 5 | cut -d "=" -f 2`
	if [ -z $NIC ];then
		NIC="physical NIC was not allocated"
	fi
	echo "VNET   : $PNIC $PNAM" >> $work_out/vnet.tmp
	echo "=== Confirm added virtual networks will be made ==="
	echo "-------------------------------------------------------------------" >> $work_out/vnet.info
 	echo "VNET   :" $PNIC | tee -a $work_out/vnet.info
	echo "VSW    :" $PNAM | tee -a $work_out/vnet.info
	echo "NIC    :" $NIC | tee -a $work_out/vnet.info
done

echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Select OS install
############################################################################

header "$TITLE" "$PATTERN"
print "# OS Install                                                                     [7/7]"
print ""
printf "Select a method to install the Oracle Solaris OS on the logical domain %s.\n" "$DOMAIN"
print "Please select either installation from a network install server for from an iso image"
print "file."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

os_install 0

print ""
echo "=== The following method will be set ==="
cat $work_out/os.info
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting VC
############################################################################

echo "VC     : the virtual console concentrator is $VCC " >> $work_out/vc.info
echo "VC     : the port number is $VCPORT" >> $work_out/vc.info
echo "VC     : $VCC $VCPORT" >> $work_out/vc.tmp

############################################################################
# Setting Variables
############################################################################

echo "OBP    : auto-boot?=$AUTOBOOT" >> $work_out/var.tmp

############################################################################
# Confirmation of setting
############################################################################

header "$TITLE" "$PATTERN"
print "The following I/O domain configuration will be set."
print ""
printf "======= Your configuration information for I/O domain %s =========================\n" "$DOMAIN"
cat $work_out/dom.tmp
cat $work_out/cpu.info
cat $work_out/mem.tmp
print "-------------------------------------------------------------------"
cat $work_out/add_io.tmp
print "-------------------------------------------------------------------"
cat $work_out/vnet.info
print "-------------------------------------------------------------------"
cat $work_out/os.info
print "-------------------------------------------------------------------"
cat $work_out/vc.info
cat $work_out/var.tmp
print "======================================================================================="
print ""

############################################################################
# Execution and creating of configuration file
############################################################################

EXE=$conf_dir/${DOMAIN}-${DATE}.sh

save_exec 0

############################################################################
# Delete temporary file 
############################################################################

delete
############################################################################

}
