#/bin/bash
#
# All Rights Reserved, Copyright (c) FUJITSU LIMITED 2012-2014
#
#	Configuration Tool for Oracle VM Server for SPARC
#
# Revision 2.2  2014/10/02
#
# pattern4_web.sh

guest_pattern4_web()
{

#---set default------------------------------------------------------------#
DOMAIN="webdom"
CPU_MIN=1
CPU_DEF=1
MEM_MIN=4096
MEM_DEF=4096
AUTOBOOT=false
PVNET="primary-vsw0,vnet0"
LVNET="io-vsw-pub0,vnet1 io-vsw-pub1,vnet2 io-vsw-local0,vnet3"
VCC=primary-vcc0
VCPORT=5010
VDS="io-vds-web"
MIN_VDISK=1
#--------------------------------------------------------------------------#
TITLE=" 5.Configure a guest Domain (for Web server) "
DKIND="guest"
PATTERN="Pattern 4"
work_out="${work_dir}"

#--------------------------------------------------------------------------#

############################################################################
# Display of result 
# P1: file name
# P2: sepalate pattarn( 0:none 1:top 2:inline )
############################################################################
display_rst()
{
FILE=`ls -l $work_dir|grep drwxr-xr-x|awk -F" " '{print $9}'`
for i in $FILE
do
	case $2 in
		[0])	cat $work_dir/$i/$1
			;;
		[1])	echo " [ $i ]----------------------"
			cat $work_dir/$i/$1
			;;
		[2])	while read line
			do
				echo "$line  ($i)"
			done < $work_dir/$i/$1
			;;
	esac
done
}
############################################################################
# Creating Domain 
############################################################################

header "$TITLE" "$PATTERN"
print "# Logical domain quantity                                                        [1/8]"
print ""
print "Create some guest domains for use as a web server."
print "Specify the quantity of guest domains."
print "The host name for created guest domains will be given automatically."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

NUM=1
domain_no

NUM_DOM=`expr $NUM`
GUEST_COUNT=0
while [ $GUEST_COUNT -lt $NUM_DOM ]
do
	work_work="${work_dir}/${DOMAIN}${GUEST_COUNT}"
	mkdir $work_work > /dev/null 2>&1
	echo "Domain : $DOMAIN$GUEST_COUNT" >> $work_work/dom.tmp
	GUEST_COUNT=`expr $GUEST_COUNT + 1`
done

echo ""
echo "=== The following logical domain name will be set ==="
display_rst dom.tmp 0
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Assign CPU
############################################################################

print_cpu
header "$TITLE" "$PATTERN"
print "# CPU core                                                                       [2/8]"
print ""
print "Assign CPU cores to guest domains."
print "CPU cores of the same quantity will be set to all domains."
print ""
print "### Current CPU allocation for each domain ###"
print ""
cat $work_dir/cpulist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_cpu 1

GUEST_COUNT=0
while [ $GUEST_COUNT -lt $NUM_DOM ]
do
	work_work="${work_dir}/${DOMAIN}${GUEST_COUNT}"
	CPU_COMM=(`cat $work_out/cpu.tmp`)
	echo "CPU    : ${CPU_COMM[2]} cores for the $DKIND domain $DOMAIN$GUEST_COUNT." >> $work_work/cpu.info
	if [ "${CPU_COMM[3]}" = "enabled" ];then
		echo "CPU    : The parameter of \"max-cores\" enabled" >> $work_work/cpu.info
	else
		echo "CPU    : The parameter of \"max-cores\" disabled" >> $work_work/cpu.info
	fi
	cp $work_out/cpu.tmp $work_work/cpu.tmp

	GUEST_COUNT=`expr $GUEST_COUNT + 1`
done

echo "=== The following quantity of CPU cores will be allocated ==="
display_rst cpu.info 1
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting Memory
############################################################################

header "$TITLE" "$PATTERN"
print_memory

print "# Memory                                                                         [3/8]"
print ""
print "Assign memory to guest domains."
print "The same memory size will be set to all domains."
print ""
print "### The current amount of memory allocated to each domain ###"
print ""
cat $work_dir/memlist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_memory

GUEST_COUNT=0
while [ $GUEST_COUNT -lt $NUM_DOM ]
do
	work_work="${work_dir}/${DOMAIN}${GUEST_COUNT}"
	MEM_COMM=`cat $work_out/mem.tmp`
	echo $MEM_COMM | sed -e "s/\./$GUEST_COUNT./" >> $work_work/mem.tmp
	GUEST_COUNT=`expr $GUEST_COUNT + 1`
done

echo "=== The following memory will be allocated ==="
display_rst mem.tmp 0
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Confirm VNET( management LAN )
############################################################################

header "$TITLE" "$PATTERN"
print "# VNET                                                                           [4/8]"
print ""
print "These VNETs (Virtual Network) are created for the system management of the web server."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

GUEST_COUNT=0
while [ $GUEST_COUNT -lt $NUM_DOM ]
do
	work_work="${work_dir}/${DOMAIN}${GUEST_COUNT}"
	LP=0
	for i in $PVNET
	do
		PNAM=`echo $i|awk -F","  '{print $1}'`
		PNIC=`echo $i|awk -F","  '{print $2}'`
		NIC=`ldm ls -l -p | grep VSW | grep $PNAM | cut -d "|" -f 5 | cut -d "=" -f 2`
		if [ -z $NIC ];then
			NIC="physical NIC was not allocated"
		fi
		echo "VNET   : $PNIC $PNAM" >> $work_work/vnet.tmp
		if [ $LP -gt 0 ];then
			echo "----------------------------" >> $work_work/vnet.info
		fi
	 	echo "VNET   :" $PNIC >> $work_work/vnet.info
		echo "VSW    :" $PNAM >> $work_work/vnet.info
		echo "NIC    :" $NIC  >> $work_work/vnet.info
		LP=`expr $LP + 1`
	done
	GUEST_COUNT=`expr $GUEST_COUNT + 1`
done

echo "=== Confirm added virtual networks will be made ==="
display_rst vnet.info 1
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Confirm VNET( internal )
############################################################################

header "$TITLE" "$PATTERN"
print "# VNET                                                                           [5/8]"
print ""
print "These VNETs (Virtual Network) are created for the external LAN connection and the "
print "Inter-Domain connection."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

GUEST_COUNT=0
while [ $GUEST_COUNT -lt $NUM_DOM ]
do
	work_work="${work_dir}/${DOMAIN}${GUEST_COUNT}"
	LP=0
	for i in $LVNET
	do
		PNAM=`echo $i|awk -F","  '{print $1}'`
		PNIC=`echo $i|awk -F","  '{print $2}'`
		NIC=`ldm ls -l -p | grep VSW | grep $PNAM | cut -d "|" -f 5 | cut -d "=" -f 2`
		if [ -z $NIC ];then
			NIC="physical NIC was not allocated"
		fi
		echo "VNET   : $PNIC $PNAM" >> $work_work/vnet.tmp
		if [ $LP -gt 0 ];then
			echo "----------------------------" >> $work_work/vnet1.info
		fi
	 	echo "VNET   :" $PNIC >> $work_work/vnet1.info
		echo "VSW    :" $PNAM >> $work_work/vnet1.info
		echo "NIC    :" $NIC  >> $work_work/vnet1.info
		LP=`expr $LP + 1`
	done
	GUEST_COUNT=`expr $GUEST_COUNT + 1`
done

cp $work_work/vnet.tmp $work_dir
echo "=== Confirm added virtual networks will be made ==="
display_rst vnet1.info 1
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Confirm VDS
############################################################################

DOM_ORG=$DOMAIN
GUEST_COUNT=0
while [ $GUEST_COUNT -lt $NUM_DOM ]
do
	header "$TITLE" "$PATTERN"

	print "# Virtual Disk                                                                   [6/8]"
	print ""
	printf "How many create a virtual disk (vdisk) for %s ?\n" "$DOMAIN$GUEST_COUNT"
	print ""
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""

	DOMAIN=$DOM_ORG$GUEST_COUNT
	work_out="${work_dir}/${DOMAIN}"
	make_vdisk 1 1 $VDS
	GUEST_COUNT=`expr $GUEST_COUNT + 1`
done

DOMAIN=$DOM_ORG

work_out=$work_dir
if [ -f $work_out/gvds.info ];then
	echo ""
	echo "=== The following virtual disk configurations have been set ==="
	display_rst gvds.info 1
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Select OS install
############################################################################

header "$TITLE" "$PATTERN"
print "# OS Install                                                                     [7/8]"
print ""
printf "Select a method to install the Oracle Solaris OS on the logical domain %s.\n" "$DOMAIN"
print "Please select either installation from a network install server for from an iso image"
print "file."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

os_install 0

GUEST_COUNT=0
while [ $GUEST_COUNT -lt $NUM_DOM ]
do
	work_work="${work_dir}/${DOMAIN}${GUEST_COUNT}"
	if [ -f $work_out/os.tmp ];then
		cp $work_out/os.tmp $work_work
	fi
	cp $work_out/os.info $work_work
	GUEST_COUNT=`expr $GUEST_COUNT + 1`
done

echo "=== The following method will be set ==="
display_rst os.info 1
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting VC
############################################################################

header "$TITLE" "$PATTERN"
print "# Virtual Console                                                                [8/8]"
print ""
print "A virtual console (vc) is set to access to each domain's console. "
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

GUEST_COUNT=0
VCP=$VCPORT
while [ $GUEST_COUNT -lt $NUM_DOM ]
do
	work_work="${work_dir}/${DOMAIN}${GUEST_COUNT}"
	echo "VC     : the virtual console concentrator is $VCC " >> $work_work/vc.info
	echo "VC     : the port number is $VCP" >> $work_work/vc.info
	echo "VC     : $VCC $VCP" >> $work_work/vc.tmp
	VCP=`expr $VCP + 1`
	GUEST_COUNT=`expr $GUEST_COUNT + 1`
done

echo "=== The following virtual console settings will be made ==="
display_rst vc.info 1
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting Variables
############################################################################

GUEST_COUNT=0
while [ $GUEST_COUNT -lt $NUM_DOM ]
do
	work_work="${work_dir}/${DOMAIN}${GUEST_COUNT}"
	echo "OBP    : auto-boot?=$AUTOBOOT" >> $work_work/var.tmp
	GUEST_COUNT=`expr $GUEST_COUNT + 1`
done

############################################################################
# Confirmation of setting
############################################################################

header "$TITLE" "$PATTERN"
print "The following guest domain configuration will be set."
print ""

FILE=`ls -l $work_dir|grep drwxr-xr-x|awk -F" " '{print $9}'`
for i in $FILE
do
	printf "======= Your configuration information for guest domain %s =========================\n" "$i"
	cat $work_dir/$i/dom.tmp
	cat $work_dir/$i/cpu.info
	cat $work_dir/$i/mem.tmp
	print "-------------------------------------------------------------------"
	cat $work_dir/$i/vnet.info
	print "-------------------------------------------------------------------"
	cat $work_dir/$i/vnet1.info
	print "-------------------------------------------------------------------"
	if [ -f $work_dir/$i/gvds.info ];then
		cat $work_dir/$i/gvds.info
		print "-------------------------------------------------------------------"
	fi
	cat $work_dir/$i/os.info
	print "-------------------------------------------------------------------"
	cat $work_dir/$i/vc.info
	cat $work_dir/$i/var.tmp
	print "======================================================================================="
	print ""
done

############################################################################
# Execution and creating of configuration file
############################################################################

EXE=$conf_dir/${DOMAIN}-${DATE}.sh

save_exec 1

############################################################################
# Delete temporary file 
############################################################################

delete
############################################################################

}
